==> haskell-generically-0.1.1-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-generically.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 generically
version:              0.1.1
visibility:           public
id:                   generically-0.1.1-A1cwUfxhFJpASwhH2td5us
key:                  generically-0.1.1-A1cwUfxhFJpASwhH2td5us
license:              BSD-3-Clause
copyright:            2022 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus
synopsis:             Generically newtype to use with DerivingVia
description:
    This is a compatibility package as @Generically@ and @Generically1@ newtypes
    are available since @base-4.17@ in '\''GHC.Generics'\''.

category:             Generics
abi:                  eef5ca1624a05fb3c4dba95af6dc56f7
exposed:              True
exposed-modules:      GHC.Generics.Generically
import-dirs:          /usr/lib/ghc-9.4.8/site-local/generically-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/generically-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/generically-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-generically
hs-libraries:         HSgenerically-0.1.1-A1cwUfxhFJpASwhH2td5us
depends:
    base-4.17.2.1 base-orphans-0.9.1-HJdmWkjGoqQKTZL3Y0OqDy

haddock-interfaces:   /usr/share/doc/haskell-generically/html/generically.haddock
haddock-html:         /usr/share/doc/haskell-generically/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-generically-0.1.1-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-generically.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 generically
version:              0.1.1
visibility:           public
id:                   generically-0.1.1-JQ9N9dlDfYKDIE3PsnMKmm
key:                  generically-0.1.1-JQ9N9dlDfYKDIE3PsnMKmm
license:              BSD-3-Clause
copyright:            2022 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus
synopsis:             Generically newtype to use with DerivingVia
description:
    This is a compatibility package as @Generically@ and @Generically1@ newtypes
    are available since @base-4.17@ in '\''GHC.Generics'\''.

category:             Generics
abi:                  a63cf1cecff3ac366281391084b84658
exposed:              True
exposed-modules:      GHC.Generics.Generically
import-dirs:          /usr/lib/ghc-9.4.8/site-local/generically-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/generically-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/generically-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-generically
hs-libraries:         HSgenerically-0.1.1-JQ9N9dlDfYKDIE3PsnMKmm
depends:
    base-4.17.2.1 base-orphans-0.9.1-BUfLtxR8YIXF8bhKUfzdHE

haddock-interfaces:   /usr/share/doc/haskell-generically/html/generically.haddock
haddock-html:         /usr/share/doc/haskell-generically/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
